@@ -1,5 +1,5 @@
 package Telegram::Bot::Brain;
-$Telegram::Bot::Brain::VERSION = '0.008';
+$Telegram::Bot::Brain::VERSION = '0.009';
 # ABSTRACT: A base class to make your very own Telegram bot
 
 
@@ -17,7 +17,7 @@ has ua         => sub { Mojo::UserAgent->new->inactivity_timeout(shift->longpoll
 has token      => sub { croak "you need to supply your own token"; };
 
 has tasks      => sub { [] };
-has listeners => sub { [] };
+has listeners  => sub { [] };
 
 has log        => sub { Log::Any->get_logger };
 
@@ -52,6 +52,17 @@ sub add_listener {
   my $self = shift;
   my $crit = shift;
   my $resp = shift;
+  my $args = shift || {};
+
+  if (ref $crit eq 'Regexp') {
+    my $regex = qr/$crit/;
+    my $new_crit = sub {
+      my ($self, $msg) = @_;
+      return if ! defined $msg->text;
+      return $msg->text =~ $regex;
+    };
+    $crit = $new_crit;
+  }
 
   push @{ $self->listeners }, { criteria => $crit, response => $resp };
 }
@@ -71,8 +82,8 @@ sub send_to_chat_id {
   if (my $res = $tx->success) { return $tx->res->json->{result}; }
   else {
     my $err = $tx->error;
-    die "$err->{code} response: $err->{message}" if $err->{code};
-    die "Connection error: $err->{message}";
+    die "$err->{code} response: $err->{message}\nBody: " . $tx->res->body if $err->{code};
+    die "Connection error: $err->{message}\nBody: " . $tx->res->body;
   }
 }
 
@@ -90,8 +101,8 @@ sub send_message_to_chat_id {
   if (my $res = $tx->success) { return $tx->res->json->{result}; }
   else {
     my $err = $tx->error;
-    die "$err->{code} response: $err->{message}" if $err->{code};
-    die "Connection error: $err->{message}";
+    die "$err->{code} response: $err->{message}\nBody: " . $tx->res->body if $err->{code};
+    die "Connection error: $err->{message}\nBody: " . $tx->res->body;
   }
 }
 
@@ -163,7 +174,7 @@ Telegram::Bot::Brain - A base class to make your very own Telegram bot
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -209,12 +220,16 @@ Respond to messages we receive. It takes two arguments
 
 =item *
 
-a CODEREF to be executed to evaluate if we should respond to this message
+a CODEREF to be executed to evaluate if we should respond to this message or a regular expression to be matched against
 
 =item *
 
 a CODEREF to be executed if the previous criteria was true
 
+=item *
+
+an optional hashref of arguments
+
 =end
 
 =back
